@@ -27,7 +27,11 @@ our @EXPORT_OK = qw(
     x
 );
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0101';
+
+=head1 NAME
+
+idi - Easy Command-line MIDI
 
 =head1 SYNOPSIS
 
@@ -94,7 +98,9 @@ Default: C<64>
 
 =head2 w
 
-Write score
+Write score.  Supply a string argument for different name.
+
+Default filename: C<idi.mid>
 
 =head2 x
 
@@ -103,6 +109,16 @@ No-op (with C<MIDI::Simple::noop>)
 =for Pod::Coverage filename
 =for Pod::Coverage score
 
+=head1 AUTHOR
+
+Gene Boggs <gene@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2021 by Gene Boggs.
+
+This is free software, licensed under: The Artistic License 2.0 (GPL Compatible)
+
 =cut
 
 my $self;
